copyWith method
Create a copy of the current instance and override zero or more values.
Implementation
MiddlewareFile copyWith({String? name, String? path}) {
return MiddlewareFile(
name: name ?? this.name,
path: path ?? this.path,
);
}
Create a copy of the current instance and override zero or more values.
MiddlewareFile copyWith({String? name, String? path}) {
return MiddlewareFile(
name: name ?? this.name,
path: path ?? this.path,
);
}